# cfbfastR-py
<!-- badges: start -->

![Lifecycle:experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg?style=for-the-badge&logo=github)
![Contributors](https://img.shields.io/github/contributors/saiemgilani/cfbfastR-py?style=for-the-badge)
[![Twitter
Follow](https://img.shields.io/twitter/follow/cfbfastR?color=blue&label=%40cfbfastR&logo=twitter&style=for-the-badge)](https://twitter.com/cfbfastR)

<!-- badges: end -->


See [CHANGELOG.md](CHANGELOG.md) for details.

The goal of [cfbfastR-py](https://github.com/saiemgilani/cfbfastR-py) is to provide the community with a python package for working with CFB data as a companion to the [cfbfastR](https://github.com/saiemgilani/cfbfastR) R package. Beyond data aggregation and tidying ease, one of the multitude of services that [cfbfastR-py](https://github.com/saiemgilani/cfbfastR-py) provides is for benchmarking open-source expected points and win probability metrics.

## Installation

cfbfastR-py can be installed via pip:

```bash
pip install cfbfastR-py
```

or from the repo (which may at times be more up to date):

```bash
git clone https://github.com/saiemgilani/cfbfastR-py
cd cfbfastR-py
pip install -e .
```